# Kaise Gradient

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Kaiser Fechner (2024)

## Examples of How To Use (Buggy Alpha Version)

Using a Vector

```python
from kaiservectors import *
Vector2d(1, 1) - Vector2d(5, 5)
# returns Vector2d(-4, -4)
```
